@@ -1,4 +1,3 @@
-import json
 from flask import Flask, request
 from rainbond_python.parameter import Parameter
 from rainbond_python.error_handler import error_handler
@@ -7,21 +6,21 @@ app = Flask(__name__)
 error_handler(app)
 
 
-@app.route('/api/1.0/demo', methods=['GET', 'POST', 'PUT', 'DELETE'])
-def api_demo():
+@app.route('/api/v1/demo', methods=['GET', 'POST', 'PUT', 'DELETE'])
+def api_v1_demo():
     parameter = Parameter(request)
 
     if parameter.method == 'GET':
-        return json.dumps(parameter.param_url, ensure_ascii=False), 200, []
+        return parameter.param_url
 
     elif parameter.method == 'POST':
-        return json.dumps(parameter.param_json, ensure_ascii=False), 200, []
+        return parameter.param_json
 
     elif parameter.method == 'PUT':
-        return json.dumps(parameter.param_json, ensure_ascii=False), 200, []
+        return parameter.param_json
 
     elif parameter.method == 'DELETE':
-        return json.dumps(parameter.param_json, ensure_ascii=False), 200, []
+        return parameter.param_json
 
 
 if __name__ == '__main__':
